@@ -29,7 +29,7 @@ const (
 )
 
 func defaultContainerdArchives() []File {
-	const nerdctlVersion = "0.22.2"
+	const nerdctlVersion = "0.23.0"
 	location := func(goarch string) string {
 		return "https://github.com/containerd/nerdctl/releases/download/v" + nerdctlVersion + "/nerdctl-full-" + nerdctlVersion + "-linux-" + goarch + ".tar.gz"
 	}
@@ -37,12 +37,12 @@ func defaultContainerdArchives() []File {
 		{
 			Location: location("amd64"),
 			Arch:     X8664,
-			Digest:   "sha256:2b4a099fbc30bd9959b0034f3c3e73a011ea8c76aa7e20139862313aef576e61",
+			Digest:   "sha256:2097ffb95c6ce3d847ca4882867297b5ab80e3daea6f967e96ce00cc636981b6",
 		},
 		{
 			Location: location("arm64"),
 			Arch:     AARCH64,
-			Digest:   "sha256:73ecaa66e9d2debbe6a1c47a3ca0bbc14d3e6f9e99f2f5a5a28129c2d745f0ba",
+			Digest:   "sha256:d25171f8b6fe778b77ff0830a8e17bd61c68af69bd734fb9d7f4490e069a7816",
 		},
 		// No riscv64
 	}
@@ -70,10 +70,10 @@ func MACAddress(uniqueID string) string {
 // matching rule terminates the search).
 //
 // Exceptions:
-// - Mounts are appended in d, y, o order, but "merged" when the Location matches a previous entry;
-//   the highest priority Writable setting wins.
-// - DNS are picked from the highest priority where DNS is not empty.
-// - CACertificates Files and Certs are uniquely appended
+//   - Mounts are appended in d, y, o order, but "merged" when the Location matches a previous entry;
+//     the highest priority Writable setting wins.
+//   - DNS are picked from the highest priority where DNS is not empty.
+//   - CACertificates Files and Certs are uniquely appended
 func FillDefault(y, d, o *LimaYAML, filePath string) {
 	if y.Arch == nil {
 		y.Arch = d.Arch
@@ -343,10 +343,10 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 	if len(y.Network.VDEDeprecated) > 0 && len(y.Networks) == 0 {
 		for _, vde := range y.Network.VDEDeprecated {
 			network := Network{
-				Interface:  vde.Name,
-				MACAddress: vde.MACAddress,
-				SwitchPort: vde.SwitchPort,
-				VNL:        vde.VNL,
+				Interface:            vde.Name,
+				MACAddress:           vde.MACAddress,
+				SwitchPortDeprecated: vde.SwitchPort,
+				VNLDeprecated:        vde.VNL,
 			}
 			y.Networks = append(y.Networks, network)
 		}
@@ -357,20 +357,38 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 	iface := make(map[string]int)
 	for _, nw := range append(append(d.Networks, y.Networks...), o.Networks...) {
 		if i, ok := iface[nw.Interface]; ok {
-			if nw.VNL != "" {
-				networks[i].VNL = nw.VNL
-				networks[i].SwitchPort = nw.SwitchPort
+			if nw.VNLDeprecated != "" {
+				networks[i].VNLDeprecated = nw.VNLDeprecated
+				networks[i].SwitchPortDeprecated = nw.SwitchPortDeprecated
+				networks[i].Socket = ""
+				networks[i].Lima = ""
+			}
+			if nw.Socket != "" {
+				if nw.VNLDeprecated != "" {
+					// We can't return an error, so just log it, and prefer `socket` over `vnl`
+					logrus.Errorf("Network %q has both vnl=%q and socket=%q fields; ignoring vnl",
+						nw.Interface, nw.VNLDeprecated, nw.Socket)
+				}
+				networks[i].Socket = nw.Socket
+				networks[i].VNLDeprecated = ""
+				networks[i].SwitchPortDeprecated = 0
 				networks[i].Lima = ""
 			}
 			if nw.Lima != "" {
-				if nw.VNL != "" {
+				if nw.VNLDeprecated != "" {
 					// We can't return an error, so just log it, and prefer `lima` over `vnl`
 					logrus.Errorf("Network %q has both vnl=%q and lima=%q fields; ignoring vnl",
-						nw.Interface, nw.VNL, nw.Lima)
+						nw.Interface, nw.VNLDeprecated, nw.Lima)
+				}
+				if nw.Socket != "" {
+					// We can't return an error, so just log it, and prefer `lima` over `socket`
+					logrus.Errorf("Network %q has both socket=%q and lima=%q fields; ignoring socket",
+						nw.Interface, nw.Socket, nw.Lima)
 				}
 				networks[i].Lima = nw.Lima
-				networks[i].VNL = ""
-				networks[i].SwitchPort = 0
+				networks[i].Socket = ""
+				networks[i].VNLDeprecated = ""
+				networks[i].SwitchPortDeprecated = 0
 			}
 			if nw.MACAddress != "" {
 				networks[i].MACAddress = nw.MACAddress
