@@ -9,9 +9,9 @@ import (
 	"runtime"
 	"sync"
 
+	"github.com/goccy/go-yaml"
 	"github.com/lima-vm/lima/pkg/store/dirnames"
 	"github.com/lima-vm/lima/pkg/store/filenames"
-	"gopkg.in/yaml.v2"
 )
 
 //go:embed networks.yaml
@@ -19,7 +19,7 @@ var defaultConfig []byte
 
 func DefaultConfig() (NetworksConfig, error) {
 	var config NetworksConfig
-	err := yaml.Unmarshal(defaultConfig, &config)
+	err := yaml.UnmarshalWithOptions(defaultConfig, &config, yaml.Strict())
 	return config, err
 }
 
@@ -66,7 +66,7 @@ func loadCache() {
 		if cache.err != nil {
 			return
 		}
-		cache.err = yaml.Unmarshal(b, &cache.config)
+		cache.err = yaml.UnmarshalWithOptions(b, &cache.config, yaml.Strict())
 		if cache.err != nil {
 			cache.err = fmt.Errorf("cannot parse %q: %w", configFile, cache.err)
 		}
@@ -82,6 +82,24 @@ func Config() (NetworksConfig, error) {
 	return cache.config, cache.err
 }
 
+// Sock returns a socket_vmnet socket.
+func Sock(name string) (string, error) {
+	loadCache()
+	if cache.err != nil {
+		return "", cache.err
+	}
+	if err := cache.config.Check(name); err != nil {
+		return "", err
+	}
+	if cache.config.Paths.SocketVMNet == "" {
+		return "", errors.New("socketVMNet is not set")
+	}
+	return cache.config.Sock(name), nil
+}
+
+// VDESock returns a vde socket.
+//
+// Deprecated. Use Sock.
 func VDESock(name string) (string, error) {
 	loadCache()
 	if cache.err != nil {
@@ -90,5 +108,8 @@ func VDESock(name string) (string, error) {
 	if err := cache.config.Check(name); err != nil {
 		return "", err
 	}
+	if cache.config.Paths.VDEVMNet == "" {
+		return "", errors.New("vdeVMnet is not set")
+	}
 	return cache.config.VDESock(name), nil
 }
