@@ -9,10 +9,11 @@ type NetworksConfig struct {
 }
 
 type Paths struct {
-	VDESwitch string `yaml:"vdeSwitch"`
-	VDEVMNet  string `yaml:"vdeVMNet"`
-	VarRun    string `yaml:"varRun"`
-	Sudoers   string `yaml:"sudoers,omitempty"`
+	SocketVMNet string `yaml:"socketVMNet"`
+	VDESwitch   string `yaml:"vdeSwitch"` // Deprecated
+	VDEVMNet    string `yaml:"vdeVMNet"`  // Deprecated
+	VarRun      string `yaml:"varRun"`
+	Sudoers     string `yaml:"sudoers,omitempty"`
 }
 
 const (
