@@ -1,6 +1,7 @@
 package store
 
 import (
+	"errors"
 	"os"
 	"path/filepath"
 	"strings"
@@ -18,6 +19,9 @@ func Instances() ([]string, error) {
 	}
 	limaDirList, err := os.ReadDir(limaDir)
 	if err != nil {
+		if errors.Is(err, os.ErrNotExist) {
+			return nil, nil
+		}
 		return nil, err
 	}
 	var names []string
@@ -25,6 +29,9 @@ func Instances() ([]string, error) {
 		if strings.HasPrefix(f.Name(), ".") || strings.HasPrefix(f.Name(), "_") {
 			continue
 		}
+		if !f.IsDir() {
+			continue
+		}
 		names = append(names, f.Name())
 	}
 	return names, nil
